#!/bin/bash
# adriane-common.sh
# Global and local configuration, macros for ADRIANE
# (C) Klaus Knopper 2007

# Global variables
PATH="/bin:/sbin:/usr/bin:/usr/sbin:/usr/X11R6/bin:/usr/local/bin"
export PATH

DIALOG="dialog"
# ADRIANE under X
if [ -n "$DISPLAY" ] && type -t Xdialog >/dev/null 2>&1; then
 DIALOG="Xdialog"
 export XDIALOG_HIGH_DIALOG_COMPAT=1
fi

# Defaults, overwritten by /ec/adriane/adriane.conf and local config
LINES="25"
COLUMNS="80"
TERM="linux"
# Language dependent settings
LANG="de_DE@euro"
LC_LANG="de_DE@euro"
LC_MESSAGES="de_DE@euro"
# Default text editor
EDITOR="nano -t"
VIEWER="nano -t -v"
# Bluetooth/Serial devices
SOCKET_SMS="/dev/rfcomm0"
SOCKET_BRAILLE="/dev/rfcomm1"
SOCKET_GPRS="/dev/rfcomm1"
# Default parameters for espeak
ESPEAK_VOICE="de"
ESPEAK_PITCH="80"
ESPEAK_SPEED="100"
# Commands without options
COMMAND_WWW="elinks"
COMMAND_EMAIL="mutt"
COMMAND_CHAT="irssi"
COMMAND_SPEAK="espeak"

# Source common functions & global variables
# (/etc/adriane/adriane.conf, $HOME/.adriane/adriane.conf)

# Global configuration
[ -r "/etc/adriane/adriane.conf" ] && . "/etc/adriane/adriane.conf"

# User configuration
[ -r "$HOME/.adriane/adriane.conf"] && . "$HOME/.adriane/adriane.conf"

TMP="/tmp/adriane.tmp.$$"

bailout(){
 rm -f "$TMP" "$TMP".err "$TMP".pass "$TMP".list "$TMP".msg
 exit $1
}

trap bailout 1 2 3 15

# Set braille device friendly screen size
if [ -z "$DISPLAY" ]; then
 if [ "$LINES" -gt "0" ] >/dev/null 2>&1; then
  export LINES
  stty rows "$LINES"
 fi
 if [ "$COLUMNS" -gt "0" ] >/dev/null 2>&1; then
  export COLUMNS
  stty cols "$COLUMNS"
 fi
 [ -n "$TERM" ] && export TERM
fi

[ -n "$EDITOR" ]      && export EDITOR
[ -n "$LANG" ]        && export LANG
[ -n "$LANGUAGE" ]    && export LANGUAGE
[ -n "$LINGUAS" ]     && export LINGUAS
[ -n "$LC_LANG" ]     && export LC_LANG
[ -n "$LC_MESSAGES" ] && export LC_MESSAGES

# Common functions
say(){
 if [ -z "$DISPLAY" ]; then
  echo "$1"
  echo "$1" | $COMMAND_SPEAK -v"$ESPEAK_VOICE" -p"$ESPEAK_PITCH" -s"$ESPEAK_SPEED" >/dev/null 2>&1
 fi
}

# Produce a continuous number from anything that looks like a number.
numbertostderr(){
 echo "$1" 2>/dev/null | tr -d '[:alpha:][:blank:][:cntrl:][:punct:]' >&2
}

